@@ -3,25 +3,25 @@ package List::AllUtils;
 use strict;
 use warnings;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
+
+use List::Util 1.45      ();
+use List::SomeUtils 0.50 ();
+use List::UtilsBy 0.10   ();
 
-# List::Util does not define an :all tag
 BEGIN {
-    use List::Util 1.45 ();
-    List::Util->import(@List::Util::EXPORT_OK);
+    my %imported;
+    for my $module (qw( List::Util List::SomeUtils List::UtilsBy )) {
+        my @ok = do {
+            ## no critic (TestingAndDebugging::ProhibitNoStrict)
+            no strict 'refs';
+            @{ $module . '::EXPORT_OK' };
+        };
 
-    use List::SomeUtils 0.50 ();
+        $module->import( grep { !$imported{$_} } @ok );
 
-    use List::UtilsBy 0.10 ();
-
-    my %imported = map { $_ => 1 } @List::Util::EXPORT_OK;
-    List::SomeUtils->import( grep { !$imported{$_} }
-            @List::SomeUtils::EXPORT_OK );
-
-    %imported = map { $_ => 1 } @List::Util::EXPORT_OK,
-        @List::SomeUtils::EXPORT_OK;
-    List::ByUtils->import( grep { !$imported{$_} }
-            @List::ByUtils::EXPORT_OK );
+        @imported{@ok} = ($module) x @ok;
+    }
 }
 
 use base 'Exporter';
@@ -50,7 +50,7 @@ List::AllUtils - Combines List::Util, List::SomeUtils and List::UtilsBy in one b
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -1349,7 +1349,7 @@ Yanick Champoux <yanick@babyl.dyndns.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
 
